==> eclipse-orion-5.0-win32.win32.x86_64.zip: eclipse/plugins/org.eclipse.orion.client.ui_2.0.0.v20140227-0406/web/orion/settings/nls/root/messages.js <==
/*******************************************************************************
 * @license
 * Copyright (c) 2012 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License v1.0
 * (http://www.eclipse.org/legal/epl-v10.html), and the Eclipse Distribution
 * License v1.0 (http://www.eclipse.org/org/documents/edl-v10.html).
 *
 ******************************************************************************/

//NLS_CHARSET=UTF-8
/*global define */

define({
	"Plugin Description": "Plugin Description",
	"Create": "Create",
	"Loading...": "Loading...",
	"Label:": "Label:",
	"Title": "Title",
	"Plugins": "Plugins",
	"User Profile": "User Profile",
	"Git": "Git",
	"Git Settings": "Git Settings",
	"General": "General",
	"Navigation": "Navigation",
	"Links": "Links",
	"Open in same tab": "Open in same tab",
	"Open in new tab": "Open in new tab",
	"Font": "Font",
	"Family": "Family",
	"Sans Serif": "Sans Serif",
	"Serif": "Serif",
	"Size": "Size",
	"8pt": "8pt",
	"9pt": "9pt",
	"10pt": "10pt",
	"12pt": "12pt",
	"Color": "Color",
	"Background": "Background",
	"Strings": "Strings",
	"String Types": "String Types",
	"blue": "blue",
	"Weight": "Weight",
	"Normal": "Normal",
	"Bold": "Bold",
	"Comments": "Comments",
	"Comment Types": "Comment Types",
	"green": "green",
	"Keywords": "Keywords",
	"Keyword Types": "Keyword Types",
	"darkred": "darkred",
	"Categories": "Categories",
	"Username": "Username",
	"Full Name": "Full Name",
	"Email Address": "Email Address",
	"Email Confirmed": "Email Confirmed",
	"Account": "Account",
	"Current Password": "Current Password",
	"New Password": "New Password",
	"Verify Password": "Verify Password",
	"Password": "Password",
	"OpenId": "OpenId",
	"AOL": "AOL",
	"Yahoo": "Yahoo",
	"Google": "Google",
	"Unlink": "Unlink",
	"Link": "Link",
	"Unlinked": "Unlinked",
	"Linked": "Linked",
	"Linked Accounts": "Linked Accounts",
	"Git Email Address": "Git Email Address",
	"Git Username": "Git Username",
	"Git Credentials Storage": "Git Credentials Storage",
	"Update": "Update",
	"Update Profile Settings": "Update Profile Settings",
	"Update Git User Settings": "Update Git User Settings",
	"Update Git Credentials": "Update Git Credentials",
	"User profile data successfully updated.": "User profile data successfully updated.",
	"Git user data successfully updated.": "Git user data successfully updated.",
	"Git Credentials successfully updated.": "Git Credentials successfully updated.",
	"Edit Plugin JavaScript": "Edit Plugin JavaScript",
	"Install Plugin": "Install Plugin",
	"Plugin Name:": "Plugin Name:",
	"Author Name:": "Author Name:",
	"Licence:": "Licence:",
	"Description:": "Description:",
	"A plugin for Eclipse Orion": "A plugin for Eclipse Orion",
	"Plugin Link": "Plugin Link",
	"Install": "Install",
	"Install a plugin by specifying its URL": "Install a plugin by specifying its URL",
	"Plugin URL:": "Plugin URL:",
	"Disable": "Disable",
	"DisableTooltip": "Disable the plugin",
	"Enable": "Enable",
	"EnableTooltip": "Enable the plugin",
	"Reload all": "Reload all",
	"Reload all installed plugins": "Reload all installed plugins",
	"Create a new Orion Plugin": "Create a new Orion Plugin",
	"Find More Orion Plugins": "Find More Orion Plugins",
	"Get Plugins": "Get Plugins",
	"Reload": "Reload",
	"Reload the plugin": "Reload the plugin",
	"Delete": "Delete",
	"Delete this plugin from the configuration": "Delete this plugin from the configuration",
	"Type a plugin url here ...": "Type a plugin url here ...",
	"Installed ": "Installed ",
	"Installing ": "Installing ",
	"Already installed": "Already installed",
	" plugin": " plugin",
	"Reloaded ": "Reloaded ",
	"Uninstalled ": "Uninstalled ",
	"Are you sure you want to uninstall '": "Are you sure you want to uninstall '",
	"Services": "Services",
	"Value": "Value",
	"JavaScript Object": "JavaScript Object",
	"click here, then check javascript console to drill down": "click here, then check javascript console to drill down",
	"Item": "Item",
	"Git Config": "Git Config",
	"Clear Git Credentials": "Clear Git Credentials",
	"Enable Storage": "Enable Storage",
	"Please be aware that your credentials will be stored persistently in the browser." : "Please be aware that your credentials will be stored persistently in the browser.",
	"Do you wish to enable the Key Storage?" : "Do you wish to enable the Key Storage?",
	"general": "General",
	"validation": "Validation",
	"Deleted git credentials for ${0}": "Deleted git credentials for ${0}",
	"Editor": "Editor",
	"editorSettings": "Settings",
	"EditorThemes": "Themes",
	"Import": "Import",
	"Import a theme": "Import a theme",
	"Export": "Export",
	"Export a theme": "Export a theme",
	"Theme name:": "Theme name:",
	"yourTheme": "yourTheme",
	"fileManagement" : "File Management",
	"typing": "Typing",
	"autoSave": "Auto Save",
	"autoSaveTimeout": "Save interval (ms)",
	"autoLoad": "Auto Load",
	"saveDiffs": "Save file as diffs",
	"trimTrailingWhiteSpace": "Trim Trailing Whitespace on Save",
	"Restore": "Restore Defaults",
	"Default": "Default",
	"keys": "Keys",
	"tabs": "Tabs",
	"tabSize": "Tab Size",
	"expandTab": "Insert spaces for tabs",
	"smoothScrolling": "Smooth Scrolling",
	"scrollAnimation": "Scrolling Animation",
	"scrollAnimationTimeout": "Scrolling Duration (ms)",
	"keyBindings": "Key Bindings",
	"rulers": "Rulers",
	"annotationRuler": "Show Annotation Ruler",
	"lineNumberRuler": "Show Line Number Ruler",
	"foldingRuler": "Show Folding Ruler",
	"overviewRuler": "Show Overview Ruler",
	"whitespaces": "White Spaces",
	"wrapping": "Wrapping",
	"wordWrap": "Word Wrap",
	"showMargin": "Show Margin",
	"marginOffset": "Margin Column",
	"showTabs": "Show Tabs",
	"showSpaces": "Show Spaces",
	"autoSaveTimeoutInvalid": "Invalid save interval.",
	"scrollAnimationTimeoutInvalid": "Invalid scrolling duration.",
	"tabSizeInvalid": "Invalid tab size.",
	"localSettingsTooltip" : "Toggle whether this setting is shown in the local editor settings drop down.",
	"editorSettingsInfo": "Use the ${0} and ${1} to toggle whether a given setting is shown in the local editor settings drop down ${2}.",
	"autoPairParentheses": "Autopair (Parentheses)",
	"autoPairBraces": "Autopair {Braces}",
	"autoPairSquareBrackets": "Autopair [Square] Brackets",
	"autoPairAngleBrackets": "Autopair <Angle> Brackets",
	"autoPairQuotations": 'Autopair "Strings"',
	"autoCompleteComments": "Autocomplete /** Block Comments */",
	"smartIndentation": "Smart Indentation",
	"sourceControl": "Source Control",
	"showBlame": "Show Blame",
	"languageTools": "Language Tools",
	"showOccurrences": "Show Occurrences",
	"contentAssistAutoTrigger": "Show Content Assist automatically",
	"Editor preferences updated": "Editor preferences updated",
	"Editor defaults restored": "Editor defaults restored",
	"Theme": "Theme",
	"Font Size": "Font Size",
	"New Theme Name:": "New Theme Name:",
	"Font Size:": "Font Size:",
	"UI Theme": "UI Theme",
	"Navigation Bar": "Navigation Bar",
	"Navigation Text": "Navigation Text",
	"Search Box": "Search Box",
	"Tool Panel": "Tool Panel",
	"Selection Bar": "Selection Bar",
	"Location": "Location",
	"Content": "Content",
	"Main Panel": "Main Panel",
	"Button": "Button",
	"Button Text": "Button Text",
	"Section Text": "Section Text",
	"Side Panel": "Side Panel",
	"Line Color": "Line Color",
	"Line Numbers": "Line Numbers",
	"Foreground": "Foreground",
	"Current Line": "Current Line",
	"HTML Attribute": "HTML Attribute",
	"Overview Ruler": "Overview Ruler",
	"HTML Tag": "HTML Tag",
	"Annotation Ruler": "Annotation Ruler",
	"Show Guide": "Show Guide",
	"Check Guide": "Check Guide",
	"Cancel": "Cancel",
	"Revert Theme": "Revert Theme",
	"Update Theme": "Update Theme",
	"Theme:": "Theme:",
	"clickDiagram": "Click diagram to style.",
	"clickUpdate": "Click Update button to save preview.",
	"CSS Class Name": "CSS Class Name",
	"CSS Attribute": "CSS Attribute",
	"CSS Value": "CSS Value",
	"CSS Text": "CSS Text",
	"COLOR:": "Color:",
	"NEW COLOR:": "New Color:",
	"Ok": "Ok",
	"OR HEX:": "Or Hex: "
});

==> eclipse-orion-6.0-win32.win32.x86_64.zip: eclipse/plugins/org.eclipse.orion.client.ui_2.0.0.v20140629-0222/web/orion/settings/nls/root/messages.js <==
/*******************************************************************************
 * @license
 * Copyright (c) 2012 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License v1.0
 * (http://www.eclipse.org/legal/epl-v10.html), and the Eclipse Distribution
 * License v1.0 (http://www.eclipse.org/org/documents/edl-v10.html).
 *
 ******************************************************************************/

//NLS_CHARSET=UTF-8
/*global define */

define({
	"Plugin Description": "Plugin Description",
	"Create": "Create",
	"Loading...": "Loading...",
	"Label:": "Label:",
	"Title": "Title",
	"Plugins": "Plugins",
	"User Profile": "User Profile",
	"Git": "Git",
	"Git Settings": "Git Settings",
	"General": "General",
	"Navigation": "Navigation",
	"Links": "Links",
	"Open in same tab": "Open in same tab",
	"Open in new tab": "Open in new tab",
	"Font": "Font",
	"Family": "Family",
	"Sans Serif": "Sans Serif",
	"Serif": "Serif",
	"Size": "Size",
	"8pt": "8pt",
	"9pt": "9pt",
	"10pt": "10pt",
	"12pt": "12pt",
	"Color": "Color",
	"Background": "Background",
	"Strings": "Strings",
	"String Types": "String Types",
	"blue": "blue",
	"Weight": "Weight",
	"Normal": "Normal",
	"Bold": "Bold",
	"Comments": "Comments",
	"Comment Types": "Comment Types",
	"green": "green",
	"Keywords": "Keywords",
	"Keyword Types": "Keyword Types",
	"darkred": "darkred",
	"Categories": "Categories",
	"Username": "Username",
	"Full Name": "Full Name",
	"Email Address": "Email Address",
	"Email Confirmed": "Email Confirmed",
	"Account": "Account",
	"Current Password": "Current Password",
	"New Password": "New Password",
	"Verify Password": "Verify Password",
	"Password": "Password",
	"OpenId": "OpenId",
	"AOL": "AOL",
	"Yahoo": "Yahoo",
	"Google": "Google",
	"Unlink": "Unlink",
	"Link": "Link",
	"Unlinked": "Unlinked",
	"Linked": "Linked",
	"Linked Accounts": "Linked Accounts",
	"Git Email Address": "Git Email Address",
	"Git Username": "Git Username",
	"Git Credentials Storage": "Git Credentials Storage",
	"Update": "Update",
	"Update Profile Settings": "Update Profile Settings",
	"Update Git User Settings": "Update Git User Settings",
	"Update Git Credentials": "Update Git Credentials",
	"User profile data successfully updated.": "User profile data successfully updated.",
	"Git user data successfully updated.": "Git user data successfully updated.",
	"Git Credentials successfully updated.": "Git Credentials successfully updated.",
	"Edit Plugin JavaScript": "Edit Plugin JavaScript",
	"Install Plugin": "Install Plugin",
	"Plugin Name:": "Plugin Name:",
	"Author Name:": "Author Name:",
	"Licence:": "Licence:",
	"Description:": "Description:",
	"A plugin for Eclipse Orion": "A plugin for Eclipse Orion",
	"Plugin Link": "Plugin Link",
	"Install": "Install",
	"Install a plugin by specifying its URL": "Install a plugin by specifying its URL",
	"Plugin URL:": "Plugin URL:",
	"Disable": "Disable",
	"DisableTooltip": "Disable the plugin",
	"Enable": "Enable",
	"EnableTooltip": "Enable the plugin",
	"Reload all": "Reload all",
	"Reload all installed plugins": "Reload all installed plugins",
	"Create a new Orion Plugin": "Create a new Orion Plugin",
	"Find More Orion Plugins": "Find More Orion Plugins",
	"Get Plugins": "Get Plugins",
	"Reload": "Reload",
	"Reload the plugin": "Reload the plugin",
	"Delete": "Delete",
	"Delete this plugin from the configuration": "Delete this plugin from the configuration",
	"DeleteUser" : "Delete User Profile as well as workspaces and projects",
	"DeleteUserComfirmation" : "WARNING: This will permanently delete your user profile as well all your work!",
	"Type a plugin url here ...": "Type a plugin url here ...",
	"Installed ": "Installed ",
	"Installing ": "Installing ",
	"Already installed": "Already installed",
	" plugin": " plugin",
	"Reloaded ": "Reloaded ",
	"Uninstalled ": "Uninstalled ",
	"Are you sure you want to uninstall '": "Are you sure you want to uninstall '",
	"Services": "Services",
	"Value": "Value",
	"JavaScript Object": "JavaScript Object",
	"click here, then check javascript console to drill down": "click here, then check javascript console to drill down",
	"Item": "Item",
	"Git Config": "Git Config",
	"Clear Git Credentials": "Clear Git Credentials",
	"Enable Storage": "Enable Storage",
	"Please be aware that your credentials will be stored persistently in the browser." : "Please be aware that your credentials will be stored persistently in the browser.",
	"Do you wish to enable the Key Storage?" : "Do you wish to enable the Key Storage?",
	"general": "General",
	"validation": "Validation",
	"Deleted git credentials for ${0}": "Deleted git credentials for ${0}",
	"Editor": "Editor",
	"editorSettings": "Settings",
	"EditorThemes": "Themes",
	"Import": "Import",
	"Import a theme": "Import a theme",
	"Export": "Export",
	"Export a theme": "Export a theme",
	"Theme name:": "Theme name:",
	"yourTheme": "yourTheme",
	"fileManagement" : "File Management",
	"typing": "Typing",
	"autoSave": "Auto Save",
	"autoSaveTimeout": "Save interval (ms)",
	"autoLoad": "Auto Load",
	"saveDiffs": "Save file as diffs",
	"trimTrailingWhiteSpace": "Trim Trailing Whitespace on Save",
	"Restore": "Restore Defaults",
	"Default": "Default",
	"keys": "Keys",
	"tabs": "Tabs",
	"tabSize": "Tab Size",
	"expandTab": "Insert spaces for tabs",
	"smoothScrolling": "Smooth Scrolling",
	"scrollAnimation": "Scrolling Animation",
	"scrollAnimationTimeout": "Scrolling Duration (ms)",
	"keyBindings": "Key Bindings",
	"rulers": "Rulers",
	"annotationRuler": "Show Annotation Ruler",
	"lineNumberRuler": "Show Line Number Ruler",
	"foldingRuler": "Show Folding Ruler",
	"overviewRuler": "Show Overview Ruler",
	"whitespaces": "White Spaces",
	"wrapping": "Wrapping",
	"wordWrap": "Word Wrap",
	"showMargin": "Show Margin",
	"marginOffset": "Margin Column",
	"showTabs": "Show Tabs",
	"showSpaces": "Show Spaces",
	"autoSaveTimeoutInvalid": "Invalid save interval.",
	"scrollAnimationTimeoutInvalid": "Invalid scrolling duration.",
	"tabSizeInvalid": "Invalid tab size.",
	"localSettingsTooltip" : "Toggle whether this setting is shown in the local editor settings drop down.",
	"editorSettingsInfo": "Use the ${0} and ${1} to toggle whether a given setting is shown in the local editor settings drop down ${2}.",
	"autoPairParentheses": "Autopair (Parentheses)",
	"autoPairBraces": "Autopair {Braces}",
	"autoPairSquareBrackets": "Autopair [Square] Brackets",
	"autoPairAngleBrackets": "Autopair <Angle> Brackets",
	"autoPairQuotations": 'Autopair "Strings"',
	"autoCompleteComments": "Autocomplete /** Block Comments */",
	"smartIndentation": "Smart Indentation",
	"sourceControl": "Source Control",
	"showBlame": "Show Blame",
	"languageTools": "Language Tools",
	"showOccurrences": "Show Occurrences",
	"contentAssistAutoTrigger": "Show Content Assist automatically",
	"Editor preferences updated": "Editor preferences updated",
	"Editor defaults restored": "Editor defaults restored",
	"Theme": "Theme",
	"Font Size": "Font Size",
	"New Theme Name:": "New Theme Name:",
	"Font Size:": "Font Size:",
	"UI Theme": "UI Theme",
	"Navigation Bar": "Navigation Bar",
	"Navigation Text": "Navigation Text",
	"Search Box": "Search Box",
	"Tool Panel": "Tool Panel",
	"Selection Bar": "Selection Bar",
	"Location": "Location",
	"Content": "Content",
	"Main Panel": "Main Panel",
	"Button": "Button",
	"Button Text": "Button Text",
	"Section Text": "Section Text",
	"Side Panel": "Side Panel",
	"Line Color": "Line Color",
	"Line Numbers": "Line Numbers",
	"Foreground": "Foreground",
	"Current Line": "Current Line",
	"HTML Attribute": "HTML Attribute",
	"Overview Ruler": "Overview Ruler",
	"HTML Tag": "HTML Tag",
	"Annotation Ruler": "Annotation Ruler",
	"Show Guide": "Show Guide",
	"Check Guide": "Check Guide",
	"Cancel": "Cancel",
	"Revert Theme": "Revert Theme",
	"Update Theme": "Update Theme",
	"Theme:": "Theme:",
	"clickDiagram": "Click diagram to style.",
	"clickUpdate": "Click Update button to save preview.",
	"CSS Class Name": "CSS Class Name",
	"CSS Attribute": "CSS Attribute",
	"CSS Value": "CSS Value",
	"CSS Text": "CSS Text",
	"COLOR:": "Color:",
	"NEW COLOR:": "New Color:",
	"Ok": "Ok",
	"OR HEX:": "Or Hex: ",
	"splitEditors": "Split Editors",
	"splitOrientation": "Split Orientation",
	"horizontal": "Horizontal",
	"vertical": "Vertical"
});
